<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "gfxpartner_slope";

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('redux_demo/opt_name', $opt_name);

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */

$sampleHTML = '';
if (file_exists(dirname(__FILE__) . '/info-html.html')) {
    Redux_Functions::initWpFilesystem();

    global $wp_filesystem;

    $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
}

// Background Patterns Reader
$sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
$sample_patterns_url = ReduxFramework::$_url . '../sample/patterns/';
$sample_patterns = array();

if (is_dir($sample_patterns_path)) {

    if ($sample_patterns_dir = opendir($sample_patterns_path)) {
        $sample_patterns = array();

        while (($sample_patterns_file = readdir($sample_patterns_dir)) !== false) {

            if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                $name = explode('.', $sample_patterns_file);
                $name = str_replace('.' . end($name), '', $sample_patterns_file);
                $sample_patterns[] = array(
                    'alt' => $name,
                    'img' => $sample_patterns_url . $sample_patterns_file
                );
            }
        }
    }
}

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => __('Theme Panel', 'slope-core'),
    'page_title'           => __('Theme Panel', 'slope-core'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    'show_options_object'  => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'themeoptions',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )
);


// Panel Intro text -> before the form
if (!isset($args['global_variable']) || $args['global_variable'] !== false) {
    if (!empty($args['global_variable'])) {
        $v = $args['global_variable'];
    } else {
        $v = str_replace('-', '_', $args['opt_name']);
    }
    //$args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'redux-framework-demo' ), $v );
} else {
    //$args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo' );
}

// Add content after the form.
//$args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'redux-framework-demo' );

Redux::setArgs($opt_name, $args);

Redux::disable_demo();

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id'      => 'redux-help-tab-1',
        'title'   => __('Theme Information 1', 'redux-framework-demo'),
        'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
    ),
    array(
        'id'      => 'redux-help-tab-2',
        'title'   => __('Theme Information 2', 'redux-framework-demo'),
        'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = __('<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo');
Redux::setHelpSidebar($opt_name, $content);


/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

/*
As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
*/

// -> START Basic Fields
Redux::setSection(
    $opt_name,
    array(
        'title'            => __('General', 'slope-core'),
        'id'               => 'general',
        'desc'             => __('General settings', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-wrench-alt',
        'fields'           => array(
            array(
                'title'          => __('Global font select', 'slope-core'),
                'type'           => 'typography',
                'id'             => 'global_font_select',
                'google'         => true,
                'font-backup'    => true,
                'font-style'     => false,
                'font-weight'    => false,
                'font-size'      => false,
                'line-height'    => false,
                'word-spacing'   => false,
                'letter-spacing' => false,
                'text-align'     => false,
                'text-transform' => false,
                'color'          => false,
                'output'         => array('body'),
                'subtitle'       => __('Select the font to be used in the theme.', 'slope-core')
            ),
            array(
                'title'    => __('Enable custom scroll bar', 'slope-core'),
                'subtitle' => __('Replace the default scrollbar on the site with a custom one.', 'slope-core'),
                'id'       => 'enable_custom_scrollbar',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Enable lazy loading for images', 'slope-core'),
                'subtitle' => __('Lazy load the images on the site to improve speed.', 'slope-core'),
                'id'       => 'enable_lazy_loading_images',
                'type'     => 'switch',
                'default'  => false
            ),
            array(
                'title'    => __('Enable lazy loading for images', 'slope-core'),
                'subtitle' => __('Lazy load the images on the site to improve speed.', 'slope-core'),
                'id'       => 'enable_lazy_loading_images',
                'type'     => 'switch',
                'default'  => false
            ),
            array(
                'title'    => __('Global background color', 'slope-core'),
                'subtitle' => __('Sets the global background color for the entire theme. If set, it overides the Elementor\'s Background color.', 'slope-core'),
                'id'       => 'global_theme_color',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('--slope-main-color' => 'body', '--e-global-color-primary' => '.elementor-page')
            ),
            array(
                'title'    => __('Global foreground color', 'slope-core'),
                'subtitle' => __('Sets the global foreground color for the entire theme. If set, it overides the Elementor\'s Foreground color.', 'slope-core'),
                'id'       => 'global_foreground_color',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('--slope-foreground' => 'body', '--e-global-color-secondary' => '.elementor-page')
            )
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Custom Post Types', 'slope-core'),
        'id'               => 'cpt_sec',
        'desc'             => __('Settings for the custom post types', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-pencil'
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Projects', 'slope-core'),
        'id'               => 'cpt_project_sec',
        'desc'             => __('settings for the \'Projects\' post type', 'slope-core'),
        'subsection'       => true,
        'customizer_width' => '400px',
        'icon'             => 'el el-pencil',
        'fields'           => array(
            array(
                'title'    => __('Permalink text', 'slope-core'),
                'subtitle' => __('Modifies the permalink text for the \'project\' custom post type. After changing this field, go to Settings > Permalinks and then click the \'Save Changes\' button, to update the permalink structure.', 'slope-core'),
                'id'       => 'project_permalink_text',
                'type'     => 'text'
            ),
            array(
                'title'    => esc_html__('Public', 'slope-core'),
                'subtitle' => esc_html__('If on, the CPT will lead to a detail-page', 'slope-core'),
                'id'       => 'project_public',
                'type'     => 'switch',
                'default'  => true,
            )
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Services', 'slope-core'),
        'id'               => 'cpt_service_sec',
        'desc'             => __('settings for the \'Services\' post type', 'slope-core'),
        'subsection'       => true,
        'customizer_width' => '400px',
        'icon'             => 'el el-pencil',
        'fields'           => array(
            array(
                'title'    => __('Service permalink text', 'slope-core'),
                'subtitle' => __('Modifies the permalink text for the \'service\' custom post type. After changing this field, go to Settings > Permalinks and then click the \'Save Changes\' button, to update the permalink structure.', 'slope-core'),
                'id'       => 'service_permalink_text',
                'type'     => 'text'
            ),
            array(
                'title'    => esc_html__('Public', 'slope-core'),
                'subtitle' => esc_html__('If on, the CPT will lead to a detail-page', 'slope-core'),
                'id'       => 'service_public',
                'type'     => 'switch',
                'default'  => true,
            )
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Header', 'slope-core'),
        'id'               => 'header',
        'desc'             => __('Settings for the header section', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-website'
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Navigation', 'slope-core'),
        'id'               => 'navigation',
        'desc'             => __('settings for the navigation', 'slope-core'),
        'subsection'       => true,
        'customizer_width' => '400px',
        'icon'             => 'el el-website',
        'fields'           => array(
            array(
                'title'    => __('Menu image', 'slope-core'),
                'subtitle' => __('Add image to appear with the navigation menu', 'slope-core'),
                'id'       => 'navigation_menu_image',
                'type'     => 'media'
            ),
            array(
                'title'    => __('Sticky navigation', 'slope-core'),
                'subtitle' => __('If enabled, navigation will stick to the top when scrolled.', 'slope-core'),
                'id'       => 'navigation_menu_sticky',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Scrolled bar background color', 'slope-core'),
                'subtitle' => __('Sets the background color of the navigation bar when the page is scrolled.', 'slope-core'),
                'id'       => 'navigation_menu_bar_sticked_color',
                'type'     => 'color',
                'default'  => '#ffffff',
                'validate' => 'color',
                'output'   => array('background-color' => '.navigation.scrolled .navigation-bar::before')
            ),
            array(
                'title'    => __('Hamburger icon color', 'slope-core'),
                'subtitle' => __('Changes the color of the navigation opening trigger icon.', 'slope-core'),
                'id'       => 'navigation_menu_bar_hamburger_color',
                'type'     => 'color',
                'default'  => '#000000',
                'validate' => 'color',
                'output'   => array('background-color' => '.navigation .hamburger .bar')
            ),
            array(
                'title'    => __('Close icon color', 'slope-core'),
                'subtitle' => __('Changes the color of the navigation closing trigger icon.', 'slope-core'),
                'id'       => 'navigation_menu_bar_close_color',
                'type'     => 'color',
                'default'  => '#ffffff',
                'validate' => 'color',
                'output'   => array('background-color' => '.navigation.shown .hamburger .bar')
            ),
            array(
                'title'    => __('Menu background color', 'slope-core'),
                'id'       => 'navigation_menu_background_color',
                'type'     => 'color',
                'default'  => '#000000',
                'validate' => 'color',
                'output'   => array('background-color' => '.navigation .navigation-menu-menu')
            ),
            array(
                'title'    => __('Menu border color', 'slope-core'),
                'id'       => 'navigation_menu_border_color',
                'type'     => 'color',
                'default'  => '#ffffff',
                'validate' => 'color',
                'output'   => array('background-color' => '.navigation .navigation-menu')
            ),
            array(
                'title'       => __('Link formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'nav_link_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.navigation-menu-menu > ul > li > a'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for navigation link.', 'slope-core')
            )
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Preloader', 'slope-core'),
        'id'               => 'preloader',
        'desc'             => __('Settings for the preloader screen that appears while the page loads', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-refresh',
        'fields'           => array(
            array(
                'title'    => __('Preloader', 'slope-core'),
                'subtitle' => __('If enabled, a preloader screen will appear while the page loads.', 'slope-core'),
                'id'       => 'preloader_enable',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Logo', 'slope-core'),
                'subtitle' => __('It will appear on the preloader screen.', 'slope-core'),
                'id'       => 'preloader_logo_upload_header',
                'type'     => 'media'
            ),
            array(
                'title'    => __('Logo size', 'slope-core'),
                'subtitle' => __('Customize logo size', 'slope-core'),
                'id'       => 'preloader_logo_dimensions_header',
                'type'     => 'dimensions',
                'output'   => array('.preloader img')
            ),
            array(
                'title'    => __('Background color', 'slope-core'),
                'id'       => 'preloader_bg_color',
                'type'     => 'color',
                'default'  => '#000000',
                'validate' => 'color',
                'output'   => array('background-color' => '.preloader')
            ),
            array(
                'title'   => __('Inner pulse color', 'slope-core'),
                'id'      => 'preloader_inner_pulse_color',
                'type'    => 'color_rgba',
                'default' => array(
                    'color' => '#323232',
                    'alpha' => .8
                ),
            ),
            array(
                'title'   => __('Outer pulse color', 'slope-core'),
                'id'      => 'preloader_outer_pulse_color',
                'type'    => 'color_rgba',
                'default' => array(
                    'color' => '#797979',
                    'alpha' => 0
                ),
            ),
        )
    )
);

// Redux::setSection( $opt_name, array(
//     'title'            => __( 'Blog', 'slope-core' ),
//     'id'               => 'blog',
//     'desc'             => __( 'Settings for the blog', 'slope-core' ),
//     'customizer_width' => '400px',
//     'icon'             => 'el el-bullhorn',
//     'fields'           => array(
//         array(
//             'title'    => __('Sidebar location', 'slope-core'),
//             'id'       => 'blog_sidebar_location',
//             'desc'     => __('Choose the location where the sidebar should appear on the posts page.', 'slope-core'),
//             'type'     => 'image_select',
//             'options'  => array(
//                 '1'      => array(
//                     'alt'   => 'sidebar left', 
//                     'img'   => ReduxFramework::$_url.'assets/img/2cl.png'
//                 ),
//                 '2'      => array(
//                     'alt'   => 'sidebar right', 
//                     'img'  => ReduxFramework::$_url.'assets/img/2cr.png'
//                 ),
//             ),
//             'default'  => '2'
//         ),
//     )
// ));

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Single post', 'slope-core'),
        'id'               => 'single_post',
        'desc'             => __('Settings for the single blog post', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-bullhorn',
        'subsection'       => true,
        'fields'           => array(
            array(
                'title'    => __('Sidebar', 'slope-core'),
                'subtitle' => __('Display sidebar on the single post', 'slope-core'),
                'id'       => 'blog_sidebar_display',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Sidebar location', 'slope-core'),
                'subtitle' => __('Choose the location where the sidebar should appear on the post detailed page.', 'slope-core'),
                'id'       => 'blog_sidebar_location_detailed',
                'type'     => 'image_select',
                'options'  => array(
                    '1' => array(
                        'alt' => 'sidebar left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '2' => array(
                        'alt' => 'sidebar right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),
                ),
                'default'  => '2'
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Related Posts', 'slope-core'),
        'id'               => 'Related posts',
        'desc'             => __('settings for the posts', 'slope-core'),
        'customizer_width' => '400px',
        'subsection'       => true,
        'icon'             => 'el el-bullhorn',
        'fields'           => array(
            array(
                'title'    => __('Related posts', 'slope-core'),
                'subtitle' => __('Append related posts section on single posts.', 'slope-core'),
                'id'       => 'related_posts_display',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Excerpt', 'slope-core'),
                'subtitle' => __('Display excerpts with the thumbnails.', 'slope-core'),
                'id'       => 'related_posts_excerpt',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Heading', 'slope-core'),
                'subtitle' => __('Heading for the related posts section', 'slope-core'),
                'id'       => 'related_posts_heading',
                'type'     => 'text'
            ),
            array(
                'title'       => __('Heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'related_posts_heading_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.related-posts--heading h2'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for heading.', 'slope-core')
            ),
            array(
                'title'       => __('Post heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'related_posts_post_heading_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.related-posts .blog-list-single--content h2'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for post title.', 'slope-core')
            ),
            array(
                'title'       => __('Post excerpt formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'related_posts_detail_heading_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.related-posts .blog-list-single--content div a,.related-posts .blog-list-single--content div h6'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for post excerpt.', 'slope-core')
            ),
            array(
                'title'    => __('Background color for post hover', 'slope-core'),
                'id'       => 'related_posts_bg_hover',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('background-color' => '.related-posts .blog-list-single--thumbnail .hover')
            ),
            array(
                'title'    => __('icon circle color for post hover', 'slope-core'),
                'id'       => 'related_posts_icon_bg_hover',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('background-color' => '.related-posts .blog-list-single--thumbnail .hover .circle')
            ),
            array(
                'title'    => __('icon color for post hover', 'slope-core'),
                'id'       => 'related_posts_icon_color_hover',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('color' => '.related-posts .blog-list-single--thumbnail .hover .circle i')
            ),
            array(
                'title'    => __('Section background color', 'slope-core'),
                'id'       => 'related_posts_section_background_color',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('background-color' => '.related-posts')
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Fields', 'slope-core'),
        'id'               => 'fields_section',
        'desc'             => __('settings for the fields', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-align-left',
        'fields'           => array(
            array(
                'title'    => __('Border color', 'slope-core'),
                'id'       => 'fields_border_color',
                'type'     => 'color',
                'validate' => 'color',
            ),
            array(
                'title'    => __('Active border color', 'slope-core'),
                'id'       => 'fields_border_color_active',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('border-color' => 'input:focus, textarea:focus')
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Footer', 'slope-core'),
        'id'               => 'footer',
        'desc'             => __('settings for the footer section', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-laptop'
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Footer header', 'slope-core'),
        'id'               => 'footer_header',
        'desc'             => __('settings for the footer', 'slope-core'),
        'subsection'       => true,
        'customizer_width' => '400px',
        'icon'             => 'el el-laptop',
        'fields'           => array(
            array(
                'title'    => __('Footer', 'slope-core'),
                'subtitle' => __('If enabled, footer will be displayed.', 'slope-core'),
                'id'       => 'footer_show',
                'type'     => 'switch',
                'default'  => false
            ),
            array(
                'title'    => __('Logo', 'slope-core'),
                'subtitle' => __('this logo will be displayed in the footer.', 'slope-core'),
                'id'       => 'logo_upload_footer',
                'type'     => 'media'
            ),
            array(
                'title'    => __('Logo size', 'slope-core'),
                'subtitle' => __('Customize logo width and height.', 'slope-core'),
                'id'       => 'logo_dimensions_footer',
                'type'     => 'dimensions',
                'output'   => array('.footer .footer--logo a img')
            ),
            array(
                'title'    => __('Tagline', 'slope-core'),
                'subtitle' => __('Add tagline for the footer', 'slope-core'),
                'id'       => 'footer_header_tagline',
                'type'     => 'text'
            ),
            array(
                'title'       => __('Tagline formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'footer_tagline_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .footer--header .footer--paragraph .heading'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for tagline.', 'slope-core')
            ),
            array(
                'title'    => __('Background color', 'slope-core'),
                'id'       => 'footer_bg',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('background-color' => '.footer .footer--wrapper')
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Footer content', 'slope-core'),
        'id'               => 'footer_content',
        'desc'             => __('settings for the footer', 'slope-core'),
        'subsection'       => true,
        'customizer_width' => '400px',
        'icon'             => 'el el-laptop',
        'fields'           => array(
            array(
                'title'       => __('Heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'footer_header_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .detail-single h6', '.email-form label'),
                'units'       => 'px',
                'subtitle'    => __('Typography option of heading for the details.', 'slope-core')
            ),
            array(
                'title'       => __('Phone number', 'slope-core'),
                'subtitle'    => __('This phone number will appear in the footer.', 'slope-core'),
                'id'          => 'footer_phone_number',
                'type'        => 'text',
                'description' => __('First field sets the heading for the phone number and the second is for the phone number itself.'),
                'placeholder' => '',
                'data'        => array(
                    'phone_heading' => '',
                    'phone_value'   => ''
                )
            ),
            array(
                'title'       => __('Phone number formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'footer_phone_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .footer-phone-number h4'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for phone number.', 'slope-core')
            ),
            array(
                'title'       => __('Email', 'slope-core'),
                'subtitle'    => __('This email address will appear in the footer.', 'slope-core'),
                'id'          => 'footer_email',
                'type'        => 'text',
                'description' => __('First field sets the heading for the email and the second is for the email address itself.'),
                'placeholder' => '',
                'data'        => array(
                    'email_heading' => '',
                    'email_value'   => ''
                )
            ),
            array(
                'title'       => __('Email formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'footer_email_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .footer-email h4'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for email.', 'slope-core')
            ),
            array(
                'title'       => __('Address', 'slope-core'),
                'subtitle'    => __('The address will be displayed in the footer.', 'slope-core'),
                'id'          => 'footer_address',
                'type'        => 'text',
                'description' => __('First field sets the heading for the address and the second is for the address itself.'),
                'placeholder' => '',
                'data'        => array(
                    'address_heading' => '',
                    'address_value'   => ''
                )
            ),
            array(
                'title'       => __('Address formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'footer_address_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .footer-address h4'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for address.', 'slope-core')
            ),
            array(
                'title'    => __('Form', 'slope-core'),
                'subtitle' => __('If enabled, form will be displayed.', 'slope-core'),
                'id'       => 'footer_form_show',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Copyright', 'slope-core'),
                'subtitle' => __('Enter the relevant copyright information.', 'slope-core'),
                'id'       => 'footer_copyright',
                'type'     => 'text'
            ),
            array(
                'title'       => __('Copyright formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'copyright_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.footer .footer-bottom h6'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for copyright.', 'slope-core')
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Social Networks', 'slope-core'),
        'id'               => 'social_networks',
        'desc'             => __('settings for social networks', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-thumbs-up',
        'fields'           => array(
            array(
                'title'    => __('Show in header', 'slope-core'),
                'subtitle' => __('Display social networks in the header.', 'slope-core'),
                'id'       => 'social_show_header',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Show in footer', 'slope-core'),
                'subtitle' => __('Display social networks in the footer.', 'slope-core'),
                'id'       => 'social_show_footer',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Show in 404 page', 'slope-core'),
                'subtitle' => __('Display social networks in the 404 page.', 'slope-core'),
                'id'       => 'social_show_404',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Heading', 'slope-core'),
                'subtitle' => __('Enter heading for the social icons', 'slope-core'),
                'id'       => 'social_heading',
                'type'     => 'text',
            ),
            array(
                'title'       => __('Heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'social_heading_format',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.navigation-menu-social h6'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for heading.', 'slope-core')
            ),
            array(
                'title'       => __('Icon formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'social_icon_format',
                'google'      => true,
                'font-backup' => true,
                'font-family' => false,
                'output'      => array('.navigation-menu-social ul li a i'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for social icons.', 'slope-core')
            ),
            array(
                'title'    => __('Icon hover color', 'slope-core'),
                'id'       => 'social_icon_hover_color',
                'type'     => 'color',
                'validate' => 'color',
                'output'   => array('color' => '.navigation-menu-social ul li a:hover i')
            ),
            array(
                'title'    => __('Facebook', 'slope-core'),
                'id'       => 'social_facebook',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Twitter', 'slope-core'),
                'id'       => 'social_twitter',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Instagram', 'slope-core'),
                'id'       => 'social_instagram',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Youtube', 'slope-core'),
                'id'       => 'social_youtube',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Tumblr', 'slope-core'),
                'id'       => 'social_tumblr',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('LinkedIn', 'slope-core'),
                'id'       => 'social_linkedIn',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Dribbble', 'slope-core'),
                'id'       => 'social_dribbble',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Pinterest', 'slope-core'),
                'id'       => 'social_pinterest',
                'type'     => 'text',
                'validate' => 'url'
            ),
            array(
                'title'    => __('Behance', 'slope-core'),
                'id'       => 'social_behance',
                'type'     => 'text',
                'validate' => 'url'
            ),
        )
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Archives', 'slope-core'),
        'id'               => 'archives',
        'desc'             => __('settings for the archives page', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-folder-open',
        'fields'           => array(
            array(
                'title'    => __('Show sidebar', 'slope-core'),
                'subtitle' => __('Display sidebar on the archives page', 'slope-core'),
                'id'       => 'show_sidebar_archive',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Sidebar location', 'slope-core'),
                'subtitle' => __('Choose the location where the sidebar should appear on the archives page.', 'slope-core'),
                'id'       => 'archive_sidebar_location',
                'type'     => 'image_select',
                'options'  => array(
                    '1' => array(
                        'alt' => 'sidebar left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '2' => array(
                        'alt' => 'sidebar right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),
                ),
                'default'  => '2'
            ),
            array(
                'title'    => __('Show excerpt', 'slope-core'),
                'subtitle' => __('Display excerpt with post on the archives page', 'slope-core'),
                'id'       => 'show_excerpt_archive',
                'type'     => 'switch',
                'default'  => true
            ),
        ),
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('Search page', 'slope-core'),
        'id'               => 'search_page',
        'desc'             => __('settings for the search page', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-search',
        'fields'           => array(
            array(
                'title'    => __('Show sidebar', 'slope-core'),
                'subtitle' => __('Display sidebar on the search page', 'slope-core'),
                'id'       => 'show_sidebar_search',
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'title'    => __('Sidebar location', 'slope-core'),
                'subtitle' => __('Choose the location where the sidebar should appear on the search page.', 'slope-core'),
                'id'       => 'search_sidebar_location',
                'type'     => 'image_select',
                'options'  => array(
                    '1' => array(
                        'alt' => 'sidebar left',
                        'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                    ),
                    '2' => array(
                        'alt' => 'sidebar right',
                        'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                    ),
                ),
                'default'  => '2'
            ),
            array(
                'title'    => __('Show excerpt', 'slope-core'),
                'subtitle' => __('Display excerpt with post on the search page', 'slope-core'),
                'id'       => 'show_excerpt_search',
                'type'     => 'switch',
                'default'  => true
            ),
        ),
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title'            => __('404 Page', 'slope-core'),
        'id'               => '404',
        'desc'             => __('settings for the 404 page', 'slope-core'),
        'customizer_width' => '400px',
        'icon'             => 'el el-remove-sign',
        'fields'           => array(
            array(
                'title'    => __('Main heading', 'slope-core'),
                'subtitle' => __('Enter main heading for the 404 page.', 'slope-core'),
                'id'       => 'main_heading_404',
                'type'     => 'text',
            ),
            array(
                'title'       => __('Main heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'main_heading_format_404',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.not-found-content .heading-very-large'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for main heading.', 'slope-core')
            ),
            array(
                'title'    => __('Secondary heading', 'slope-core'),
                'subtitle' => __('Enter secondary heading for the 404 page.', 'slope-core'),
                'id'       => 'secondary_heading_404',
                'type'     => 'text',
            ),
            array(
                'title'       => __('Secondary heading formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'secondary_heading_format_404',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.not-found-content .heading-large'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for secondary heading.', 'slope-core')
            ),
            array(
                'title'    => __('Description', 'slope-core'),
                'subtitle' => __('Enter description for the 404 page.', 'slope-core'),
                'id'       => 'secondary_description_404',
                'type'     => 'text',
            ),
            array(
                'title'       => __('Description formatting', 'slope-core'),
                'type'        => 'typography',
                'id'          => 'description_format_404',
                'google'      => true,
                'font-backup' => true,
                'output'      => array('.not-found-content .heading.heading-medium'),
                'units'       => 'px',
                'subtitle'    => __('Typography option for description.', 'slope-core')
            ),
            array(
                'title'    => __('illustration', 'slope-core'),
                'id'       => 'illustration_404',
                'subtitle' => __('Add illustration for the 404 page.', 'slope-core'),
                'type'     => 'media'
            ),
        ),
    )
);



/*
 * <--- END SECTIONS
 */


/*
 *
 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
 *
 */

/*
 *
 * --> Action hook examples
 *
 */

// If Redux is running as a plugin, this will remove the demo notice and links
//add_action( 'redux/loaded', 'remove_demo' );

// Function to test the compiler hook and demo CSS output.
// Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

// Change the arguments after they've been declared, but before the panel is created
//add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

// Change the default value of a field after it's been set, but before it's been useds
//add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

// Dynamically add a section. Can be also used to modify sections/fields
//add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
if (!function_exists('compiler_action')) {
    function compiler_action($options, $css, $changed_values)
    {
        // echo '<h1>The compiler hook has run!</h1>';
        // echo "<pre>";
        // print_r( $changed_values ); // Values that have changed since the last save
        // echo "</pre>";
        //print_r($options); //Option values
        //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
    }
}

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')) {
    function redux_validate_callback_function($field, $value, $existing_value)
    {
        $error = false;
        $warning = false;

        //do your validation
        if ($value == 1) {
            $error = true;
            $value = $existing_value;
        } elseif ($value == 2) {
            $warning = true;
            $value = $existing_value;
        }

        $return['value'] = $value;

        if ($error == true) {
            $field['msg'] = 'your custom error message';
            $return['error'] = $field;
        }

        if ($warning == true) {
            $field['msg'] = 'your custom warning message';
            $return['warning'] = $field;
        }

        return $return;
    }
}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')) {
    function redux_my_custom_field($field, $value)
    {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if (!function_exists('dynamic_section')) {
    function dynamic_section($sections)
    {
        //$sections = array();
        $sections[] = array(
            'title'  => __('Section via hook', 'redux-framework-demo'),
            'desc'   => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo'),
            'icon'   => 'el el-paper-clip',
            // Leave this as a blank section, no options just some intro text set above.
            'fields' => array()
        );

        return $sections;
    }
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if (!function_exists('change_arguments')) {
    function change_arguments($args)
    {
        //$args['dev_mode'] = true;

        return $args;
    }
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if (!function_exists('change_defaults')) {
    function change_defaults($defaults)
    {
        $defaults['str_replace'] = 'Testing filter hook!';

        return $defaults;
    }
}

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if (!function_exists('remove_demo')) {
    function remove_demo()
    {
        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if (class_exists('ReduxFrameworkPlugin')) {
            remove_filter('plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2);

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
        }
    }
}