<?php 

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class SlopeRecentPosts extends WP_Widget {

    function __construct() {
        parent::__construct(
            'slope_recent_posts', 
            esc_html__('Slope recent posts', 'slope-core'), 
            array( 'description' => esc_html__( 'Displays recent posts in the sidebar', 'slope-core' ), ) 
        );
    }

    public function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? esc_html__( 'Recent posts', 'slope' ) : $instance['title'], $instance, $this->id_base );
        $date = !empty($instance['date']) ? (bool) $instance['date'] : false;
        $cat = !empty($instance['category']) ? (bool) $instance['category'] : false;


    echo htmlspecialchars_decode($args['before_widget']);

    if (!empty($title)){
    	echo htmlspecialchars_decode($args['before_title']) . $title . htmlspecialchars_decode($args['after_title']); 
    }?>
            <ul class="recent-posts">
                <?php 

                $r = new WP_Query(
                    apply_filters(
                        'widget_posts_args',
                        array(
                            'posts_per_page'      => $instance['posts_per_page'],
                            'post_type'           => 'post',
                            'no_found_rows'       => true,
                            'post_status'         => 'publish',
                            'ignore_sticky_posts' => true,
                        ),
                        $instance
                    )
                );
                if ( ! $r->have_posts() ) {
                    return;
                }

                foreach ( $r->posts as $recent_post ) : ?>
                <?php
                    $post_title   = get_the_title($recent_post->ID);
                    $post_thumb   = get_the_post_thumbnail($recent_post->ID, 'thumbnail');
                    $title        = (!empty($post_title)) ? $post_title : __('(no title)', 'slope-core');
                ?>
                <li class="recent-posts-single"> 
                    <?php if( $post_thumb ) { ?>
                    <div class="recent-posts-single--thumbnail">
                        <a href="<?php the_permalink( $recent_post->ID ); ?>">
                            <?php echo $post_thumb; ?>
                            <div class="hover">
                                <div class="circle">
                                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 43.75 43.564">
                                        <title>arrow</title>
                                        <path d="M1027.744,1417.179l20.61,20.61a1.172,1.172,0,0,1,0,1.658l-20.61,20.611a1.174,1.174,0,0,1-1.658,0l-.69-.692a1.171,1.171,0,0,1,0-1.657l17.431-17.431h-36.708a1.172,1.172,0,0,1-1.172-1.172v-.976a1.172,1.172,0,0,1,1.172-1.172h36.708l-17.431-17.431a1.171,1.171,0,0,1,0-1.657l.69-.691A1.174,1.174,0,0,1,1027.744,1417.179Z" transform="translate(-1004.947 -1416.836)"/>
                                    </svg>
                                </div>
                            </div>
                        </a>
                    </div>
                    <?php } ?>
                    <div class="recent-posts-single--content">
                        <?php if ($date || $cat): ?>
                        <div>
                            <?php if ($date): ?>
                            <a href="<?php echo esc_url(home_url(get_the_date('Y/m/d', $recent_post->ID))); ?>">
                                <p><?php echo esc_html(get_the_date('', $recent_post->ID )); ?></p>
                            </a>
                            <?php endif; ?>
                            <?php if ($date && $cat): ?>
                            <span>|</span>
                            <?php endif; ?>
                            <?php if ($cat):
                                $category = get_the_category($post_id = $recent_post->ID);
                                if ( !empty($category) && $category[0] ):
                            ?>
                                <a href="<?php echo esc_url(get_category_link($category[0])); ?>">
                                    <p><?php echo esc_html($category[0]->cat_name); ?></p>
                                </a>
                            <?php
                                endif;
                                if (empty($category)):
                            ?>
                                <p><?php echo esc_html__('uncategorized', 'slope-core'); ?></p>
                            <?php
                                endif;
                            ?>
                            <?php endif; ?>
                        </div>
                        <?php endif; ?>
                        <h6>
                            <a href="<?php the_permalink( $recent_post->ID ); ?>">
                            <?php  echo esc_html(wp_trim_words(get_the_title($recent_post->ID), 8, '...')); ?>
                            </a>
                        </h6>
                    </div>
                </li>
                <?php endforeach; ?>
            </ul>

    <?php 

    echo htmlspecialchars_decode($args['after_widget']);

    }

    // Widget Backend 

    public function form( $instance ) {

    // Check values

    	 $title = isset( $instance['title'] ) ? $instance['title'] : esc_html( 'Recent Posts', 'slope' );
         $date = isset($instance['date']) ? (bool) $instance['date'] : false;
         $cat = isset($instance['category']) ? (bool) $instance['category'] : false;
         $posts_per_page = isset( $instance['posts_per_page'] ) ? $instance['posts_per_page'] : 3;

    // Widget admin form

    ?>

    <p>
        <label><?php esc_html_e( 'Title:', 'slope-core' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>

        <label><?php esc_html_e( 'Number of posts to show:', 'slope-core' ); ?></label> 

        <input size="3" class="widefat" id="<?php echo esc_attr($this->get_field_id('posts_per_page')); ?>" name="<?php echo esc_attr($this->get_field_name('posts_per_page')); ?>" type="text" value="<?php echo esc_attr($posts_per_page); ?>" />
        <br />
    </p>
    <p>
        <label>
            <input type="checkbox" class="checkbox" id="<?php echo esc_attr($this->get_field_id('date')); ?>" name="<?php echo esc_attr($this->get_field_name('date')); ?>"<?php checked( $date ); ?> />

            <?php esc_html_e( 'Show date', 'slope-core' ); ?>
        </label>
    </p>
    <p>
        <label>
            <input type="checkbox" class="checkbox" id="<?php echo esc_attr($this->get_field_id('category')); ?>" name="<?php echo esc_attr($this->get_field_name('category')); ?>"<?php checked( $cat ); ?> />

            <?php esc_html_e( 'Show category', 'slope-core' ); ?>
        </label>
    </p>

    <?php

    }

    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['date'] = !empty($new_instance['date']) ? 1 : 0;
        $instance['category'] = !empty($new_instance['category']) ? 1 : 0;
        $instance['posts_per_page'] = ( ! empty( $new_instance['posts_per_page'] ) ) ? strip_tags( $new_instance['posts_per_page'] ) : '';
        return $instance;
    }

}

function register_slope_recent_posts() {
	register_widget( 'SlopeRecentPosts' );
}
add_action('widgets_init', 'register_slope_recent_posts');